==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/zh_HK.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入磁碟",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "New text file" : "新文字檔",
    "Create new text file" : "創建新文字檔案",
    "Editing session has expired. Please reload the page." : "編輯工作階段已過期。請重新載入頁面。",
    "{user} has mentioned you in the text document {node}" : "{user} 在  {node} 的文字文件中提到了您",
    "This file cannot be displayed as download is disabled by the share" : "此檔案無法顯示，因為共享已禁用下載",
    "File not found" : "找不到檔案",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
    "Overwrite the file and save the current changes" : "覆寫檔案並保存目前更新",
    "Discard the current changes and load the latest version" : "放棄目前更新並載入最新版本",
    "Reload" : "重新載入",
    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "檔案已被覆寫。無法自動儲存您目前的更新。請選擇要如何繼續。",
    "The document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網際網路連線。",
    "Reconnect" : "重新連接",
    "You've been disconnected from the server." : "您已與伺服器斷線。",
    "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它目前被 {user} 鎖上。",
    "Close outline view" : "關閉大綱檢視",
    "Outline" : "大綱",
    "Insert below" : "下方插入",
    "Click for options, hold to drag" : "點選以檢視選項，按住以拖曳",
    "Not connected. Cannot update guest name." : "未連接。無法更新訪客名字。",
    "Failed to update the guest name." : "更新訪客名字失敗",
    "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
    "Enter your name" : "輸入您的名稱",
    "Guest" : "訪客",
    "submit" : "遞交",
    "you" : "你",
    "edit" : "編輯",
    "Uploading multiple attachments failed." : "上傳多個附件失敗。",
    "Uploading attachment failed: {error}" : "上傳附件失敗：{error}",
    "Uploading attachment failed." : "附件上傳失敗。",
    "Insert an attachment" : "插入附件",
    "Failed to insert from Files" : "從檔案插入失敗",
    "Failed to create attachment" : "無法創建附件",
    "Offline since {time}." : "自 {time} 起離線。",
    "Not connected to the cloud." : "未連接到雲端。",
    "Preview options" : "預覽選項",
    "Text only" : "僅文字",
    "Show link preview" : "顯示連結預覽",
    "Open in new tab" : "以新分頁打開",
    "Copy link" : "複製連結",
    "Remove link" : "移除連結",
    "Active people" : "活躍的人",
    "guest" : "訪客",
    "Offline" : "離線",
    "Offline, changes will be saved when online" : "離線，在線時更改將被保存",
    "Saving …" : "正在儲存……",
    "Saved" : "已儲存",
    "Last saved {lastSave}" : "上次儲存於 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "Unsaved changes" : "未儲存變更",
    "Save document" : "保存文件",
    "Last saved" : "最後保存於",
    "Formatting and shortcuts" : "排版和捷徑",
    "Speed up your writing with simple shortcuts." : "使用簡單的快捷方式加快您的寫作速度。",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
    "Just type the Markdown syntax from below." : "只需輸入下方的 Markdown 語法即可。",
    "Style" : "樣式",
    "Syntax" : "語法",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "New paragraph" : "新段落",
    "Enter" : "輸入",
    "Hard line break" : "硬換行",
    "followed by" : "後接",
    "Backspace" : "Backspace",
    "Shift" : "轉移",
    "Bold" : "粗體",
    "Bold text" : "粗體文字",
    "Italic" : "斜體",
    "Italicized text" : "斜體文字",
    "Strikethrough" : "刪除線",
    "Mistaken text" : "錯誤的文字",
    "Underline" : "下面畫線",
    "Underlined text" : "下面畫線的文字",
    "Heading 1" : "標題 1",
    "Heading level 1" : "標題級別 1",
    "Heading 6" : "標題 6",
    "Heading level 6" : "標題級別 6",
    "Unordered list" : "無序清單",
    "An item" : "一個項目",
    "Ordered list" : "有序清單",
    "First item" : "第一個項目",
    "Checklist" : "清單",
    "To-Do item" : "待辦事項",
    "Blockquote" : "引文",
    "Quoted text" : "引用文字",
    "Code block" : "程式碼區塊",
    "Some code" : "一些代碼",
    "Link" : "連結",
    "Insert emoji" : "插入 emoji",
    "emoji" : "表情符號",
    "Mention someone" : "提及某人",
    "name" : "姓名",
    "Smart picker" : "聰明的選擇器",
    "something" : "某些東西",
    "Action" : "操作",
    "Undo" : "復原",
    "Redo" : "重作",
    "Toggle outline" : "切換大綱",
    "Alt" : "Alt",
    "Open link" : "打開連結",
    "Edit link" : "編輯連結",
    "Save changes" : "保存更改",
    "Cancel" : "取消",
    "URL" : "URL",
    "Edit block formula" : "編輯區塊公式",
    "Edit inline formula" : "編輯行內公式",
    "LaTeX formula" : "LaTeX 公式",
    "Save" : "保存",
    "Disabled because you are currently offline." : "因為您目前離線，所以已停用。",
    "Attachments cannot be created or uploaded because this file is shared from another cloud." : "無法創建或上傳附件，因為此檔案來自另一個雲端分享。",
    "Upload from computer" : "從電腦上傳",
    "Insert from Files" : "從檔案插入",
    "Formatting help" : "格式化說明",
    "Link to file or folder" : "連結至檔案或資料夾",
    "Link to website" : "連結至網站",
    "Update link" : "更新鏈接",
    "Open the Smart Picker" : "打開智能選擇器",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
    "Insert result" : "插入結果",
    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
    "Translate" : "翻譯",
    "Show assistant results" : "顯示小幫手結果",
    "Assistant results" : "小幫手結果",
    "Nextcloud Assistant" : "Nextcloud 小幫手",
    "Show result" : "顯示結果",
    "Delete task" : "刪除任務",
    "_%n word_::_%n words_" : ["%n 個單詞"],
    "_%n char_::_%n chars_" : ["%n 個字母"],
    "Remaining actions" : "剩餘操作",
    "Editor actions" : "編輯器操作",
    "Formatting menu bar" : "格式化選項單欄",
    "Full width editor" : "完整寬度編輯器",
    "Translate from {language}" : "從 {language} 翻譯",
    "Translate to {language}" : "翻譯為 {language}",
    "Translation failed" : "翻譯失敗",
    "To translate individual parts of the text, select it before using the translate function." : "要翻譯部份文字，請在使用翻譯功能前選取該部份。",
    "Translate from" : "翻譯從",
    "Select language" : "選擇語言",
    "Text to translate from" : "要翻譯的文字",
    "to" : "至",
    "Translate to" : "翻譯至",
    "Translated text result" : "翻譯文字結果",
    "Replace" : "取代",
    "Insert" : "插入",
    "No emoji found" : "找不到表情符號",
    "No command found" : "找不到命令",
    "No user found" : "找不到用戶",
    "No suggestion found" : "找不到建議",
    "Uploading attachments is disabled because the file is shared from another cloud." : "上傳附件已停用，因為該檔案來自另一個雲端分享。",
    "Upload" : "上傳",
    "Insert Table" : "插入數據庫表",
    "Smart Picker" : "智能選擇器",
    "Edit" : "編輯",
    "Copy code block" : "複製程式碼區塊",
    "Copy code" : "複製代碼",
    "Code block options" : "程式碼區塊選項",
    "Code block language" : "程式碼區塊語言",
    "e.g. php, javascript, json…" : "例如 php、javascript、json ...",
    "Source code" : "原始碼",
    "Diagram" : "圖表",
    "Both" : "皆是",
    "Mermaid documentation" : "Mermaid 說明書",
    "Failed to load" : "加載失敗",
    "Could not find image in attachments list." : "在附件清單中找不到影像。",
    "Delete this attachment" : "刪除此附件",
    "Delete this image" : "刪除此圖像",
    "Add row before" : "在前面添加行",
    "Add row after" : "在後面添加行",
    "Delete this row" : "刪除此行",
    "Left align column" : "左側對齊縱列",
    "Center align column" : "置中對齊縱列",
    "Right align column" : "右側對齊縱列",
    "Add column before" : "在前面添加縱列",
    "Add column after" : "在後面添加縱列",
    "Delete this column" : "删除此縱列",
    "Delete this table" : "删除此表",
    "Add row below" : "在下方新增列",
    "Show folder description" : "顯示資料夾描述",
    "Hide outline" : "隱藏大綱",
    "Show outline" : "顯示大綱",
    "Done" : "完成",
    "Headings" : "標題",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "Lists" : "清單",
    "To-Do list" : "待辦事項清單",
    "Increase indentation" : "增加縮排",
    "Decrease indentation" : "減少縮排",
    "Blocks" : "區塊",
    "Inline math" : "行內數學",
    "Block math" : "區塊數學",
    "Info callout" : "資訊標記",
    "Success callout" : "成功標記",
    "Warning callout" : "警告標記",
    "Danger callout" : "危險標記",
    "Table" : "表",
    "Details" : "細節",
    "Insert link" : "插入連結",
    "Insert attachment" : "插入附件",
    "Command" : "指令",
    "Ctrl" : "Ctrl",
    "Option" : "選項",
    "Formatting" : "正在格式化",
    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
    "Choose" : "選擇",
    "Choose {file}" : "選擇 {file}",
    "Add folder description" : "新增資料夾描述",
    "\"{name}\" already exist!" : "「{name}」已存在！",
    "Created \"{name}\"" : "已建立「{name}」",
    "Copied to the clipboard" : "已複製到剪貼板",
    "Could not copy to the clipboard" : "無法複製到剪貼簿",
    "Front matter" : "前言",
    "Link to this section" : "連結到本節",
    "Edit guest name" : "編輯訪客名稱",
    "Save guest name" : "儲存訪客名稱",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy link to clipboard" : "複製連結到剪貼板"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/zh_HK.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入磁碟",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "New text file" : "新文字檔",
    "Create new text file" : "創建新文字檔案",
    "Editing session has expired. Please reload the page." : "編輯工作階段已過期。請重新載入頁面。",
    "{user} has mentioned you in the text document {node}" : "{user} 在  {node} 的文字文件中提到了您",
    "This file cannot be displayed as download is disabled by the share" : "此檔案無法顯示，因為共享已禁用下載",
    "File not found" : "找不到檔案",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
    "Overwrite the file and save the current changes" : "覆寫檔案並保存目前更新",
    "Discard the current changes and load the latest version" : "放棄目前更新並載入最新版本",
    "Reload" : "重新載入",
    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "檔案已被覆寫。無法自動儲存您目前的更新。請選擇要如何繼續。",
    "The document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網際網路連線。",
    "Reconnect" : "重新連接",
    "You've been disconnected from the server." : "您已與伺服器斷線。",
    "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它目前被 {user} 鎖上。",
    "Insert below" : "下方插入",
    "Click for options, hold to drag" : "點選以檢視選項，按住以拖曳",
    "Not connected. Cannot update guest name." : "未連接。無法更新訪客名字。",
    "Failed to update the guest name." : "更新訪客名字失敗",
    "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
    "Enter your name" : "輸入您的名稱",
    "Guest" : "訪客",
    "submit" : "遞交",
    "you" : "你",
    "edit" : "編輯",
    "Uploading multiple attachments failed." : "上傳多個附件失敗。",
    "Uploading attachment failed: {error}" : "上傳附件失敗：{error}",
    "Uploading attachment failed." : "附件上傳失敗。",
    "Insert an attachment" : "插入附件",
    "Failed to insert from Files" : "從檔案插入失敗",
    "Failed to create attachment" : "無法創建附件",
    "Offline since {time}." : "自 {time} 起離線。",
    "Not connected to the cloud." : "未連接到雲端。",
    "Preview options" : "預覽選項",
    "Text only" : "僅文字",
    "Show link preview" : "顯示連結預覽",
    "Open in new tab" : "以新分頁打開",
    "Copy link" : "複製連結",
    "Remove link" : "移除連結",
    "Active people" : "活躍的人",
    "guest" : "訪客",
    "Offline" : "離線",
    "Offline, changes will be saved when online" : "離線，在線時更改將被保存",
    "Saving …" : "正在儲存……",
    "Saved" : "已儲存",
    "Last saved {lastSave}" : "上次儲存於 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "Unsaved changes" : "未儲存變更",
    "Save document" : "保存文件",
    "Last saved" : "最後保存於",
    "Close table of contents" : "關閉目錄",
    "Pin table of contents" : "釘選目錄",
    "Table of contents" : "目錄",
    "Formatting and shortcuts" : "排版和捷徑",
    "Speed up your writing with simple shortcuts." : "使用簡單的快捷方式加快您的寫作速度。",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
    "Just type the Markdown syntax from below." : "只需輸入下方的 Markdown 語法即可。",
    "Style" : "樣式",
    "Syntax" : "語法",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "New paragraph" : "新段落",
    "Enter" : "輸入",
    "Hard line break" : "硬換行",
    "followed by" : "後接",
    "Backspace" : "Backspace",
    "Shift" : "轉移",
    "Bold" : "粗體",
    "Bold text" : "粗體文字",
    "Italic" : "斜體",
    "Italicized text" : "斜體文字",
    "Strikethrough" : "刪除線",
    "Mistaken text" : "錯誤的文字",
    "Underline" : "下面畫線",
    "Underlined text" : "下面畫線的文字",
    "Heading 1" : "標題 1",
    "Heading level 1" : "標題級別 1",
    "Heading 6" : "標題 6",
    "Heading level 6" : "標題級別 6",
    "Unordered list" : "無序清單",
    "An item" : "一個項目",
    "Ordered list" : "有序清單",
    "First item" : "第一個項目",
    "Checklist" : "清單",
    "To-Do item" : "待辦事項",
    "Blockquote" : "引文",
    "Quoted text" : "引用文字",
    "Code block" : "程式碼區塊",
    "Some code" : "一些代碼",
    "Link" : "連結",
    "Insert emoji" : "插入 emoji",
    "emoji" : "表情符號",
    "Mention someone" : "提及某人",
    "name" : "姓名",
    "Smart picker" : "聰明的選擇器",
    "something" : "某些東西",
    "Action" : "操作",
    "Undo" : "復原",
    "Redo" : "重作",
    "Toggle outline" : "切換大綱",
    "Alt" : "Alt",
    "Open link" : "打開連結",
    "Edit link" : "編輯連結",
    "Save changes" : "保存更改",
    "Cancel" : "取消",
    "URL" : "URL",
    "Edit block formula" : "編輯區塊公式",
    "Edit inline formula" : "編輯行內公式",
    "LaTeX formula" : "LaTeX 公式",
    "Save" : "保存",
    "Disabled because you are currently offline." : "因為您目前離線，所以已停用。",
    "Attachments cannot be created or uploaded because this file is shared from another cloud." : "無法創建或上傳附件，因為此檔案來自另一個雲端分享。",
    "Upload from computer" : "從電腦上傳",
    "Insert from Files" : "從檔案插入",
    "Formatting help" : "格式化說明",
    "Link to file or folder" : "連結至檔案或資料夾",
    "Link to website" : "連結至網站",
    "Update link" : "更新鏈接",
    "Open the Smart Picker" : "打開智能選擇器",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
    "Insert result" : "插入結果",
    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
    "Translate" : "翻譯",
    "Show assistant results" : "顯示小幫手結果",
    "Assistant results" : "小幫手結果",
    "Nextcloud Assistant" : "Nextcloud 小幫手",
    "Show result" : "顯示結果",
    "Delete task" : "刪除任務",
    "_%n word_::_%n words_" : ["%n 個單詞"],
    "_%n char_::_%n chars_" : ["%n 個字母"],
    "Remaining actions" : "剩餘操作",
    "Editor actions" : "編輯器操作",
    "Formatting menu bar" : "格式化選項單欄",
    "Full width editor" : "完整寬度編輯器",
    "Translate from {language}" : "從 {language} 翻譯",
    "Translate to {language}" : "翻譯為 {language}",
    "Translation failed" : "翻譯失敗",
    "To translate individual parts of the text, select it before using the translate function." : "要翻譯部份文字，請在使用翻譯功能前選取該部份。",
    "Translate from" : "翻譯從",
    "Select language" : "選擇語言",
    "Text to translate from" : "要翻譯的文字",
    "to" : "至",
    "Translate to" : "翻譯至",
    "Translated text result" : "翻譯文字結果",
    "Replace" : "取代",
    "Insert" : "插入",
    "Edit" : "編輯",
    "No emoji found" : "找不到表情符號",
    "No command found" : "找不到命令",
    "No user found" : "找不到用戶",
    "No suggestion found" : "找不到建議",
    "Uploading attachments is disabled because the file is shared from another cloud." : "上傳附件已停用，因為該檔案來自另一個雲端分享。",
    "Upload" : "上傳",
    "Insert Table" : "插入數據庫表",
    "Smart Picker" : "智能選擇器",
    "Copy code block" : "複製程式碼區塊",
    "Copy code" : "複製代碼",
    "Code block options" : "程式碼區塊選項",
    "Code block language" : "程式碼區塊語言",
    "e.g. php, javascript, json…" : "例如 php、javascript、json ...",
    "Source code" : "原始碼",
    "Diagram" : "圖表",
    "Both" : "皆是",
    "Mermaid documentation" : "Mermaid 說明書",
    "Failed to load" : "加載失敗",
    "Could not find image in attachments list." : "在附件清單中找不到影像。",
    "Delete this attachment" : "刪除此附件",
    "Delete this image" : "刪除此圖像",
    "Add row before" : "在前面添加行",
    "Add row after" : "在後面添加行",
    "Delete this row" : "刪除此行",
    "Left align column" : "左側對齊縱列",
    "Center align column" : "置中對齊縱列",
    "Right align column" : "右側對齊縱列",
    "Add column before" : "在前面添加縱列",
    "Add column after" : "在後面添加縱列",
    "Delete this column" : "删除此縱列",
    "Delete this table" : "删除此表",
    "Add row below" : "在下方新增列",
    "Show folder description" : "顯示資料夾描述",
    "Hide outline" : "隱藏大綱",
    "Show outline" : "顯示大綱",
    "Done" : "完成",
    "Headings" : "標題",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "Lists" : "清單",
    "To-Do list" : "待辦事項清單",
    "Increase indentation" : "增加縮排",
    "Decrease indentation" : "減少縮排",
    "Blocks" : "區塊",
    "Inline math" : "行內數學",
    "Block math" : "區塊數學",
    "Info callout" : "資訊標記",
    "Success callout" : "成功標記",
    "Warning callout" : "警告標記",
    "Danger callout" : "危險標記",
    "Table" : "表",
    "Details" : "細節",
    "Insert link" : "插入連結",
    "Insert attachment" : "插入附件",
    "Command" : "指令",
    "Ctrl" : "Ctrl",
    "Option" : "選項",
    "Formatting" : "正在格式化",
    "Start writing or type '/' to add…" : "開始撰寫或輸入「/」以新增 …",
    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
    "Choose" : "選擇",
    "Choose {file}" : "選擇 {file}",
    "Add folder description" : "新增資料夾描述",
    "\"{name}\" already exist!" : "「{name}」已存在！",
    "Created \"{name}\"" : "已建立「{name}」",
    "Copied to the clipboard" : "已複製到剪貼板",
    "Could not copy to the clipboard" : "無法複製到剪貼簿",
    "Front matter" : "前言",
    "A table was pasted into a table. Nested tables are not supported." : "表格被貼上到表格中。不支援巢狀表格。",
    "Link to this section" : "連結到本節",
    "Close outline view" : "關閉大綱檢視",
    "Outline" : "大綱",
    "Edit guest name" : "編輯訪客名稱",
    "Save guest name" : "儲存訪客名稱",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy link to clipboard" : "複製連結到剪貼板"
},
"nplurals=1; plural=0;");
